==> nextcloud-21.0.5.tgz: nextcloud/apps/sharebymail/l10n/fa.js <==
OC.L10N.register(
    "sharebymail",
    {
    "Shared with %1$s" : "اشتراک گذاری با %1$s",
    "Shared with {email}" : "اشتراک گذاری با {email}",
    "Shared with %1$s by %2$s" : "اشتراک گذاری با %1$s توسط %2$s",
    "Shared with {email} by {actor}" : "اشتراک گذاری با {email} توسط {actor}",
    "Unshared from %1$s" : "عدم اشتراک از %1$s",
    "Unshared from {email}" : "عدم اشتراک از {email}",
    "Unshared from %1$s by %2$s" : "عدم اشتراک از %1$s توسط %2$s",
    "Unshared from {email} by {actor}" : "عدم اشتراک از {email} توسط {actor}",
    "Password for mail share sent to %1$s" : "رمز عبور برای اشتراک نامه ارسال شده به %1$s",
    "Password for mail share sent to {email}" : "گذرواژه برای اشتراک ایمیل ارسال شده به {email}",
    "Password for mail share sent to you" : "رمزعبور برای پست الکترونیک اشتراک شما ارسال شد",
    "You shared %1$s with %2$s by mail" : "شما %1$s با %2$s توسط پست الکترونیک به اشتراک گذاشتید.",
    "You shared {file} with {email} by mail" : "{file} را با {email} از طریق پست به اشتراک گذاشتید",
    "%3$s shared %1$s with %2$s by mail" : "%3$s اشتراک گذاری %1$s با %2$s توسط پست الکترونیک",
    "{actor} shared {file} with {email} by mail" : "{actor} به اشتراک گذاشته {file} با {email} از طریق پست",
    "You unshared %1$s from %2$s by mail" : "شما %1$s از طریق %2$s  پست مشترک نشده اید",
    "You unshared {file} from {email} by mail" : "شما {file} از {email} را از طریق پست مشترکاً اشتراک نکردید",
    "%3$s unshared %1$s from %2$s by mail" : "%3$s عدم اشتراک گذاری %1$s از %2$s توسط پست الکترونیک",
    "{actor} unshared {file} from {email} by mail" : "{actor} عدم اشتراک {file} از {email} از طریق پست الکترونیک",
    "Password to access %1$s was sent to %2s" : "رمز ورود برای دسترسی %1$s  به %2s ارسال شد",
    "Password to access {file} was sent to {email}" : "رمز عبور برای دسترسی به  {file} به {email}  ارسال شد",
    "Password to access %1$s was sent to you" : "رمز عبور برای دسترسی %1$s به شما ارسال شد",
    "Password to access {file} was sent to you" : "رمز ورود برای دسترسی به {file} برای شما ارسال شد",
    "Failed to send share by email" : "ارسال اشتراک از طریق ایمیل انجام نشد",
    "%1$s shared »%2$s« with you" : "%1$s به اشتراک گذاشته » %2$s« با شما",
    "%1$s shared »%2$s« with you." : "%1$s به اشتراک گذاشته » %2$s« با شما",
    "Click the button below to open it." : "برای باز کردن آن روی دکمه زیر کلیک کنید.",
    "Open »%s«" : "باز کن »%s«",
    "%1$s via %2$s" : "%1$s از طریق %2$s",
    "%1$s shared »%2$s« with you. You should have already received a separate mail with a link to access it." : "%1$s به اشتراک گذاشته »%2$s« با شما.\nبرای دسترسی قبلاً باید یک نامه جداگانه با یک لینک دریافت کرده باشید",
    "Password to access »%1$s« shared to you by %2$s" : "برای دسترسی به رمز عبور »%1$s« توسط شما %2$s به اشتراک گذاشته شده است",
    "Password to access »%s«" : "برای دسترسی به رمز عبور »%s«",
    "It is protected with the following password:" : "با رمز عبور زیر محافظت می شود:",
    "%1$s shared »%2$s« with you and wants to add:" : "%1$s به اشتراک گذاشته شده »%2$s« با شماست و می خواهد اضافه کند:",
    "%1$s shared »%2$s« with you and wants to add" : "%1$s به اشتراک گذاشته شده »%2$s« با شماست و می خواهد اضافه کند:",
    "»%s« added a note to a file shared with you" : "»%s« یادداشتی را به پرونده ای که با شما به اشتراک گذاشته شده است اضافه کرد",
    "You just shared »%1$s« with %2$s. The share was already sent to the recipient. Due to the security policies defined by the administrator of %3$s each share needs to be protected by password and it is not allowed to send the password directly to the recipient. Therefore you need to forward the password manually to the recipient." : "شما فقط به اشتراک گذاشته اید »%1$s« با%2$s . سهم قبلاً برای گیرنده ارسال شده بود. با توجه به سیاست های امنیتی تعریف شده توسط سرپرست %3$s هر سهم ، باید با رمز محافظت شود و مجاز نیست رمز عبور را مستقیماً به گیرنده ارسال کنید. بنابراین باید گذرواژه را به صورت دستی به گیرنده ارسال کنید.",
    "Password to access »%1$s« shared by you with %2$s" : "گذرواژه برای دسترسی »%1$s« به اشتراک گذاشته شده توسط شما %2$s",
    "This is the password:" : "این رمز عبور است:",
    "You can choose a different password at any time in the share dialog." : "می توانید در هر زمان و در گفتگوی اشتراک ، رمزعبور دیگری را انتخاب کنید.",
    "Could not find share" : "اشتراک یافت نشد",
    "Share by mail" : "اشتراک از طریق پست",
    "Share provider which allows you to share files by mail" : "ارائه دهنده به شما امکان می دهد پرونده ها را از طریق پست به اشتراک بگذارید",
    "Allows users to share a personalized link to a file or folder by putting in an email address." : "به کاربران اجازه می دهد با قرار دادن یک آدرس ایمیل ، پیوند شخصی شده را با پرونده یا پوشه به اشتراک بگذارند.",
    "Send password by mail" : "ارسال رمز عبور از طریق پست",
    "We can't send you the auto-generated password. Please set a valid email address in your personal settings and try again." : "ما نمی توانیم رمز عبور ایجاد شده را برای شما ارسال کنیم. لطفاً یک آدرس پست الکترونیک معتبر را در تنظیمات شخصی خود قرار دهید و دوباره امتحان کنید.",
    "Enforce password protection" : "اجبار برای محافظت توسط رمز عبور"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-22.2.9.tgz: nextcloud/apps/sharebymail/l10n/fa.js <==
OC.L10N.register(
    "sharebymail",
    {
    "Shared with %1$s" : "اشتراک گذاری با %1$s",
    "Shared with {email}" : "اشتراک گذاری با {email}",
    "Shared with %1$s by %2$s" : "اشتراک گذاری با %1$s توسط %2$s",
    "Shared with {email} by {actor}" : "اشتراک گذاری با {email} توسط {actor}",
    "Unshared from %1$s" : "عدم اشتراک از %1$s",
    "Unshared from {email}" : "عدم اشتراک از {email}",
    "Unshared from %1$s by %2$s" : "عدم اشتراک از %1$s توسط %2$s",
    "Unshared from {email} by {actor}" : "عدم اشتراک از {email} توسط {actor}",
    "Password for mail share sent to %1$s" : "رمز عبور برای اشتراک نامه ارسال شده به %1$s",
    "Password for mail share sent to {email}" : "گذرواژه برای اشتراک ایمیل ارسال شده به {email}",
    "Password for mail share sent to you" : "رمزعبور برای پست الکترونیک اشتراک شما ارسال شد",
    "You shared %1$s with %2$s by mail" : "شما %1$s با %2$s توسط پست الکترونیک به اشتراک گذاشتید.",
    "You shared {file} with {email} by mail" : "{file} را با {email} از طریق پست به اشتراک گذاشتید",
    "%3$s shared %1$s with %2$s by mail" : "%3$s اشتراک گذاری %1$s با %2$s توسط پست الکترونیک",
    "{actor} shared {file} with {email} by mail" : "{actor} به اشتراک گذاشته {file} با {email} از طریق پست",
    "You unshared %1$s from %2$s by mail" : "شما %1$s از طریق %2$s  پست مشترک نشده اید",
    "You unshared {file} from {email} by mail" : "شما {file} از {email} را از طریق پست مشترکاً اشتراک نکردید",
    "%3$s unshared %1$s from %2$s by mail" : "%3$s عدم اشتراک گذاری %1$s از %2$s توسط پست الکترونیک",
    "{actor} unshared {file} from {email} by mail" : "{actor} عدم اشتراک {file} از {email} از طریق پست الکترونیک",
    "Password to access %1$s was sent to %2s" : "رمز ورود برای دسترسی %1$s  به %2s ارسال شد",
    "Password to access {file} was sent to {email}" : "رمز عبور برای دسترسی به  {file} به {email}  ارسال شد",
    "Password to access %1$s was sent to you" : "رمز عبور برای دسترسی %1$s به شما ارسال شد",
    "Password to access {file} was sent to you" : "رمز ورود برای دسترسی به {file} برای شما ارسال شد",
    "Share by mail" : "اشتراک از طریق پست",
    "Sharing %1$s failed, because this item is already shared with user %2$s" : "اشتراک گذاری %1$sانجام نشد ، زیرا این مورد قبلاً با کاربر%2$s به اشتراک گذاشته شده است",
    "Failed to send share by email" : "ارسال اشتراک از طریق ایمیل انجام نشد",
    "%1$s shared »%2$s« with you" : "%1$s به اشتراک گذاشته » %2$s« با شما",
    "%1$s shared »%2$s« with you." : "%1$s به اشتراک گذاشته » %2$s« با شما",
    "Click the button below to open it." : "برای باز کردن آن روی دکمه زیر کلیک کنید.",
    "Open »%s«" : "باز کن »%s«",
    "%1$s via %2$s" : "%1$s از طریق %2$s",
    "%1$s shared »%2$s« with you. You should have already received a separate mail with a link to access it." : "%1$s به اشتراک گذاشته »%2$s« با شما.\nبرای دسترسی قبلاً باید یک نامه جداگانه با یک لینک دریافت کرده باشید",
    "Password to access »%1$s« shared to you by %2$s" : "برای دسترسی به رمز عبور »%1$s« توسط شما %2$s به اشتراک گذاشته شده است",
    "Password to access »%s«" : "برای دسترسی به رمز عبور »%s«",
    "It is protected with the following password:" : "با رمز عبور زیر محافظت می شود:",
    "%1$s shared »%2$s« with you and wants to add:" : "%1$s به اشتراک گذاشته شده »%2$s« با شماست و می خواهد اضافه کند:",
    "%1$s shared »%2$s« with you and wants to add" : "%1$s به اشتراک گذاشته شده »%2$s« با شماست و می خواهد اضافه کند:",
    "»%s« added a note to a file shared with you" : "»%s« یادداشتی را به پرونده ای که با شما به اشتراک گذاشته شده است اضافه کرد",
    "You just shared »%1$s« with %2$s. The share was already sent to the recipient. Due to the security policies defined by the administrator of %3$s each share needs to be protected by password and it is not allowed to send the password directly to the recipient. Therefore you need to forward the password manually to the recipient." : "شما فقط به اشتراک گذاشته اید »%1$s« با%2$s . سهم قبلاً برای گیرنده ارسال شده بود. با توجه به سیاست های امنیتی تعریف شده توسط سرپرست %3$s هر سهم ، باید با رمز محافظت شود و مجاز نیست رمز عبور را مستقیماً به گیرنده ارسال کنید. بنابراین باید گذرواژه را به صورت دستی به گیرنده ارسال کنید.",
    "Password to access »%1$s« shared by you with %2$s" : "گذرواژه برای دسترسی »%1$s« به اشتراک گذاشته شده توسط شما %2$s",
    "This is the password:" : "این رمز عبور است:",
    "You can choose a different password at any time in the share dialog." : "می توانید در هر زمان و در گفتگوی اشتراک ، رمزعبور دیگری را انتخاب کنید.",
    "Could not find share" : "اشتراک یافت نشد",
    "Share provider which allows you to share files by mail" : "ارائه دهنده به شما امکان می دهد پرونده ها را از طریق پست به اشتراک بگذارید",
    "Allows users to share a personalized link to a file or folder by putting in an email address." : "به کاربران اجازه می دهد با قرار دادن یک آدرس ایمیل ، پیوند شخصی شده را با پرونده یا پوشه به اشتراک بگذارند.",
    "Send password by mail" : "ارسال رمز عبور از طریق پست"
},
"nplurals=2; plural=(n > 1);");
